@@ -54,6 +54,19 @@ class NamespaceTests(unittest.TestCase):
         self.assertEqual(2, ns.get('z', 2))
         self.assertIsNone(ns.get('z'))
 
+    def test_get_non_str_key(self):
+        ns = Namespace()
+        for key in [None, True, False, 1, 2.3]:
+            with self.subTest(str(key)):
+                self.assertIsNone(ns.get(key))
+                self.assertEqual(ns.get(key, 'abc'), 'abc')
+
+    def test_contains_non_str_key(self):
+        ns = Namespace()
+        for key in [None, True, False, 1, 2.3]:
+            with self.subTest(str(key)):
+                self.assertFalse(key in ns)
+
     def test_pop(self):
         ns = Namespace()
         ns['x.y.z'] = 1
@@ -70,15 +83,15 @@ class NamespaceTests(unittest.TestCase):
     def test_nested_key_in(self):
         ns = Namespace()
         ns['x.y.z'] = 1
-        self.assertTrue('x' in ns)
-        self.assertTrue('x.y' in ns)
-        self.assertTrue('x.y.z' in ns)
-        self.assertFalse('a' in ns)
-        self.assertFalse('x.a' in ns)
-        self.assertFalse('x.y.a' in ns)
-        self.assertFalse('x.y.z.a' in ns)
-        self.assertFalse('x..y' in ns)
-        self.assertFalse(123 in ns)
+        self.assertIn('x', ns)
+        self.assertIn('x.y', ns)
+        self.assertIn('x.y.z', ns)
+        self.assertNotIn('a', ns)
+        self.assertNotIn('x.a', ns)
+        self.assertNotIn('x.y.a', ns)
+        self.assertNotIn('x.y.z.a', ns)
+        self.assertNotIn('x..y', ns)
+        self.assertNotIn(123, ns)
 
     def test_items_generator(self):
         ns = Namespace()
@@ -170,7 +183,7 @@ class NamespaceTests(unittest.TestCase):
         dic1 = namespace_to_dict(ns)
         dic2 = ns.as_dict()
         self.assertEqual(dic1, dic2)
-        self.assertFalse(dic1 is dic2)
+        self.assertIsNot(dic1, dic2)
 
     def test_dict_to_namespace(self):
         ns1 = Namespace(a=1, b=Namespace(c=2), d=[Namespace(e=3)])
