@@ -3,11 +3,26 @@
 import os
 import pathlib
 import pickle
-import jsonargparse.typing
+import unittest
 from datetime import timedelta
 from typing import Callable
-from jsonargparse.typing import RegisteredType
-from jsonargparse_tests.base import *
+from jsonargparse import ArgumentParser, CLI, Namespace, ParserError
+from jsonargparse.typing import (
+    ClosedUnitInterval,
+    Email,
+    NonNegativeFloat,
+    NonNegativeInt,
+    OpenUnitInterval,
+    Path_fr,
+    path_type,
+    PositiveFloat,
+    PositiveInt,
+    RegisteredType,
+    registered_types,
+    restricted_number_type,
+    restricted_string_type,
+)
+from jsonargparse_tests.base import TempDirTestCase
 
 
 class RestrictedNumberTests(unittest.TestCase):
@@ -166,7 +181,7 @@ class OtherTests(unittest.TestCase):
 
     def test_pickle_module_types(self):
         for otype in registered_types.values():
-            if isinstance(otype, RegisteredType) or hasattr(jsonargparse.typing, otype.__name__):
+            if isinstance(otype, RegisteredType) or hasattr(__import__('jsonargparse.typing'), otype.__name__):
                 if isinstance(otype, RegisteredType):
                     otype = otype.type_class
                 with self.subTest(str(otype)):
